@@ -17,6 +17,8 @@ use mmarinus::{perms, Map};
 use std::arch::x86_64::__cpuid_count;
 use std::sync::{Arc, RwLock};
 
+pub const AESM_SOCKET: &str = "/var/run/aesmd/aesm.socket";
+
 struct Tcs;
 
 struct Keep {
@@ -35,7 +37,7 @@ impl crate::backend::Backend for Backend {
 
     #[inline]
     fn shim(&self) -> &'static [u8] {
-        include_bytes!(concat!(env!("OUT_DIR"), "/bin/shim-sgx"))
+        include_bytes!(env!("CARGO_BIN_FILE_ENARX_SHIM_SGX"))
     }
 
     #[inline]
@@ -44,7 +46,7 @@ impl crate::backend::Backend for Backend {
     }
 
     fn data(&self) -> Vec<super::Datum> {
-        let mut data = vec![system_info(), data::dev_sgx_enclave()];
+        let mut data = vec![system_info(), data::dev_sgx_enclave(), data::aesm_socket()];
 
         data.extend(data::CPUIDS.iter().map(|c| c.into()));
 
