@@ -86,26 +86,23 @@ use std::fs::File;
 use std::os::unix::io::AsRawFd;
 
 use anyhow::Result;
+use clap::Parser;
 use log::info;
-use structopt::StructOpt;
 
 // This defines the toplevel `enarx` CLI
-#[derive(StructOpt, Debug)]
-#[structopt(
-    setting = structopt::clap::AppSettings::DeriveDisplayOrder,
-)]
+#[derive(Parser, Debug)]
 struct Options {
     /// Logging options
-    #[structopt(flatten)]
+    #[clap(flatten)]
     log: cli::LogOptions,
 
     /// Subcommands (with their own options)
-    #[structopt(flatten)]
+    #[clap(subcommand)]
     cmd: cli::Command,
 }
 
 fn main() -> Result<()> {
-    let opts = Options::from_args();
+    let opts = Options::parse();
     opts.log.init_logger();
 
     info!("logging initialized!");
@@ -130,7 +127,7 @@ fn main() -> Result<()> {
             let open_fd = modfile.as_raw_fd();
             // FIXME (v0.1.0 KEEP-CONFIG HACK): since we don't have any way to
             // pass configuration or data into a keep yet, for v0.1.0 we've
-            // just hardcoded wasmldr to assume the module is open for reading
+            // just hardcoded exec-wasmtime to assume the module is open for reading
             // on FD3. That *should* always be the case here (since nothing
             // above opens files or anything), but if that assumption is wrong
             // then things will break mysteriously later on. So this assert
@@ -163,7 +160,7 @@ fn main() -> Result<()> {
             std::process::exit(exit_code);
         }
         #[cfg(feature = "backend-sev")]
-        cli::Command::Sev(cmd) => cli::sev::run(cmd),
+        cli::Command::Snp(cmd) => cli::snp::run(cmd),
         #[cfg(feature = "backend-sgx")]
         cli::Command::Sgx(cmd) => cli::sgx::run(cmd),
     }
